Valid Urls
==========

* [Test Link1](http://www.test1.com)
* [Bad Link](http://www.badlink1.com)
* [Bad Link2](http://www.badlink2.com)
* [Bad Link3](http://www.badlink3.com)
* [Bad Link3](http://www.badlink4.com)
* [Exception](http://www.exception.com)
* [Test Link2](http://www.test2.com)
